#ifndef __ASM_ARCH_CXD9225GG_GPIO_EXT_H__
#define __ASM_ARCH_CXD9225GG_GPIO_EXT_H__

#include <linux/interrupt.h>
#include <asm/sizes.h>
#include <mach/hardware.h>
#include <asm/irq.h>



/*
 * This function is responsible for registering a GPIO signal's ISR.
 * @param pin		a name defined by \b cxd9225gg_gpio_pin_name_t
 * @param desc		an irqaction assigned to the pin's ISR
 * @return 0 if successful; non-zero otherwise.
 */
int cxd9225gg_gpio_irq_request(cxd9225gg_gpio_pin_name_t pin, struct irqaction *desc);

/*
 * Free a GPIO signal's ISR.
 * @param pin		a name defined by \b cxd9225gg_gpio_pin_name_t
 * @param desc		an irqaction assigned to the pin's ISR
 */
void cxd9225gg_gpio_irq_free(cxd9225gg_gpio_pin_name_t pin, struct irqaction *desc);


/*
 * Enable/disable a GPIO signal's interrupt.
 * @param pin         a name defined by \b cxd9225gg_gpio_pin_name_t
 * @param enable        \b #true for enabling the interrupt; \b #false otherwise
 */
void cxd9225gg_gpio_irq_enable(cxd9225gg_gpio_pin_name_t pin, bool enable);

/*
 * Set a GPIO pin's interrupt edge
 * @param pin         a name defined by \b cxd9225gg_gpio_pin_name_t
 * @param icr           one of the values defined in \b gpio_edge_t
 *                      to indicate how to generate an interrupt
 */
int cxd9225gg_gpio_irq_set_type(cxd9225gg_gpio_pin_name_t pin, gpio_int_cfg_t cfg);


/*!
 *@brief cxd9225gg_gpio_config_mux - just configure the mode of the gpio pin.
 *@param pin   a pin name as defined in \b #cxd9225gg_gpio_pin_name_t
 *@param mode  a module as define in \b #cxd9225gg_gpio_mux_mode_t;
 *	GPIO_MUX_GPIO set pin to work as GPIO port
 *	GPIO_MUX_UART set pin to work as UART
 *	GPIO_MUX_CSI set pin to work as CSI
 *@return      0 if successful, Non-zero otherwise
 */
int cxd9225gg_gpio_config_mux(cxd9225gg_gpio_pin_name_t pin, cxd9225gg_gpio_mux_mode_t mode);

/*!
 * This function is just used to request a pin and configure it.
 * @param pin	a pin name as defined in \b #cxd9225gg_gpio_pin_name_t
 * @param mode	a module as define in \b #cxd9225gg_gpio_mux_mode_t;
 * @return	0 if successful, Non-zero otherwise
 */
int cxd9225gg_gpio_request_mux(cxd9225gg_gpio_pin_name_t pin, cxd9225gg_gpio_mux_mode_t mode);


/*!
 * This function is just used to release a pin.
 * @param pin	a pin name as defined in \b #cxd9225gg_gpio_pin_name_t
 * @return	none
 */
void cxd9225gg_gpio_free_mux(cxd9225gg_gpio_pin_name_t pin);

#endif				/* __ASM_ARCH_CXD9225GG_GPIO_H__ */
