/*
 * Copyright (C) 2014 Sony Corporation
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2, as
 * published by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef __UPD72020X_H
#define __UPD72020X_H

/*
 * Renesas Electronics uPD720201 & uPD720202
 * USB3.0 Host Controller Register
 *
 *  Version : 2.0.2.6 : November 12th, 2013
 */

#define UPD_VIDR                  0x00
#define UPD_DIDR                  0x02
#define UPD_FWDCSR                0xF4
#define UPD_FWDATA0R              0xF8
#define UPD_FWDATA1R              0xFC

#define UPD_VID_720201           0x1912
#define UPD_VID_720202           0x1912

#define UPD_DID_720201           0x0014
#define UPD_DID_720202           0x0015

#define UPD_FWDCSR_SHIFT_DE       0
#define UPD_FWDCSR_SHIFT_DL       1
#define UPD_FWDCSR_SHIFT_RC       4
#define UPD_FWDCSR_SHIFT_SDATA0   8
#define UPD_FWDCSR_SHIFT_SDATA1   9

/* Except FW Download Enable, all fields are 0
 * It means:
 *   FW Download Enable
 *   FW Download unLock
 *   The result of FW Download is Invalid (no result yet)
 *   Data0 & Data1 download is completed.
 */
#define UPD_FWDCSR_FREE           0x01

/* FW Download Enable */
#define UPD_FWDCS_DE              (0x01 << UPD_FWDCSR_SHIFT_DE)
/* FW Download Disable */
#define UPD_FWDCS_DD              (0x00 << UPD_FWDCSR_SHIFT_DE)
/* Download Request DATA0, DATA1 */
#define UPD_FWDCS_DR_DATA0        (0x01 << UPD_FWDCSR_SHIFT_SDATA0)
#define UPD_FWDCS_DR_DATA1        (0x01 << UPD_FWDCSR_SHIFT_SDATA1)
/* Result Code: Invalid (no result yet) */
#define UPD_FWDCS_RC_INV          (0x00 << UPD_FWDCSR_SHIFT_RC)
/* Result Code: Success */
#define UPD_FWDCS_RC_SUCC         (0x01 << UPD_FWDCSR_SHIFT_RC)
/* Result Code: Error */
#define UPD_FWDCS_RC_ERR          (0x02 << UPD_FWDCSR_SHIFT_RC)

#define UPD_FWDCS_MASK_DE         (0x01 << UPD_FWDCSR_SHIFT_DE)
#define UPD_FWDCS_MASK_DL         (0x01 << UPD_FWDCSR_SHIFT_DL)
#define UPD_FWDCS_MASK_RC         (0x07 << UPD_FWDCSR_SHIFT_RC)
#define UPD_FWDCS_MASK_SDATA0     (0x01 << UPD_FWDCSR_SHIFT_SDATA0)
#define UPD_FWDCS_MASK_SDATA1     (0x01 << UPD_FWDCSR_SHIFT_SDATA1)

#ifndef CONFIG_EXTRA_FIRMWARE
#error "CONFIG_EXTRA_FIRMWARE no defined"
#else
#define UPD_FIRMWARE_NAME         CONFIG_EXTRA_FIRMWARE
#endif

/* The timeout(ms) threshold to get the result of FW Download */
#define UPD_FWDCSR_CHECK_TIME_THRESHOLD  30

#endif
